import * as React from 'react';

const useClickOutside = (ref, onClickOutside) => {
  const [isActive, setActive] = React.useState(false);

  const mousedown = e => {
    const {
      current
    } = ref;

    if (current !== null && !current.contains(e.target)) {
      setActive(true);
      onClickOutside(e);
    }
  };

  const mouseup = e => {
    const {
      current
    } = ref;

    if (current !== null && !current.contains(e.target)) {
      setActive(false);
    }
  };

  React.useEffect(() => {
    document.addEventListener('mousedown', mousedown);
    document.addEventListener('mouseup', mouseup);
    return () => {
      document.removeEventListener('mousedown', mousedown);
      document.removeEventListener('mouseup', mouseup);
    };
  }, [onClickOutside]);
  return [isActive];
};

export default useClickOutside;